"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
var _prettier = _interopRequireDefault(require("prettier"));
var _PathsParser = require("./PathsParser");
var _SelectionFormatter = require("./SelectionFormatter");
const prettyGql = value => {
  return _prettier.default.format(value.trim(), {
    parser: "graphql"
  });
};
describe("SelectionFormatter", () => {
  const formatPaths = paths => {
    const parser = new _PathsParser.PathsParser();
    const formatter = new _SelectionFormatter.SelectionFormatter();
    const selection = parser.parse(paths);
    return formatter.formatSelection(selection);
  };
  it("should handle fragments with new syntax", () => {
    const paths = ["content.[Hero].title", "content.[Hero].subtitle", "content.[Feature].name", "content.[Feature].description"];
    const formatted = formatPaths(paths);
    const snapshot = /* GraphQL */`
            {
                content {
                    ... on Feature {
                        description
                        name
                    }
                    ... on Hero {
                        subtitle
                        title
                    }
                }
            }
        `;
    expect(prettyGql(formatted)).toBe(prettyGql(snapshot));
  });
  it("should handle nested fragments with new syntax", () => {
    const paths = ["sections.[Hero].content.[Image].url", "sections.[Hero].content.[Text].body"];
    const formatted = formatPaths(paths);
    const snapshot = /* GraphQL */`
            {
                sections {
                    ... on Hero {
                        content {
                            ... on Image {
                                url
                            }
                            ... on Text {
                                body
                            }
                        }
                    }
                }
            }
        `;
    expect(prettyGql(formatted)).toBe(prettyGql(snapshot));
  });
});

//# sourceMappingURL=SelectionFormatter.test.js.map