"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.savePageAssets = void 0;
var _loadJsonFile = _interopRequireDefault(require("load-json-file"));
var _fsExtra = _interopRequireDefault(require("fs-extra"));
var _path = _interopRequireDefault(require("path"));
var _downloadInstallFiles = _interopRequireDefault(require("./downloadInstallFiles"));
/**
 * Type comes from installation/files/data/pagesFilesData.json
 */

const savePageAssets = async ({
  context
}) => {
  if (process.env.NODE_ENV === "test") {
    return {};
  }
  const INSTALL_EXTRACT_DIR = await (0, _downloadInstallFiles.default)();
  const pagesFilesData = await (0, _loadJsonFile.default)(_path.default.join(INSTALL_EXTRACT_DIR, "data/pagesFilesData.json"));
  try {
    const filesToUpload = pagesFilesData.map(file => {
      const buffer = _fsExtra.default.readFileSync(_path.default.join(INSTALL_EXTRACT_DIR, "images/", file.__physicalFileName));
      return {
        buffer,
        id: file.id,
        key: file.key,
        name: file.name,
        size: buffer.length,
        type: file.type,
        hideInFileManager: Boolean(file.meta.private),
        keyPrefix: "demo-pages"
      };
    });

    // Upload file to File Manager.
    const files = await context.fileManager.storage.uploadFiles({
      files: filesToUpload
    });
    return files.reduce((acc, file) => ({
      ...acc,
      [file.id]: file
    }), {});
  } catch (e) {
    console.error(e);
    console.error(`[savePageAssets]: ${e.stack}`);
  }
  return {};
};
exports.savePageAssets = savePageAssets;

//# sourceMappingURL=savePageAssets.js.map