"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.GzipContentCompressionPlugin = void 0;
var _ContentCompressionPlugin = require("./ContentCompressionPlugin");
var _gzip = require("@webiny/utils/compression/gzip");
const GZIP_COMPRESSION = "gzip";
const TO_STORAGE_ENCODING = "base64";
const FROM_STORAGE_ENCODING = "utf8";
const convertToBuffer = value => {
  if (typeof value === "string") {
    return Buffer.from(value, TO_STORAGE_ENCODING);
  }
  return value;
};

/**
 * The GZIP compression for content field.
 */
class GzipContentCompressionPlugin extends _ContentCompressionPlugin.ContentCompressionPlugin {
  constructor() {
    super(GZIP_COMPRESSION);
  }
  canCompress() {
    return true;
  }
  canDecompress(value) {
    if (!value || !value.compression) {
      return false;
    }
    return value.compression === GZIP_COMPRESSION;
  }
  async compress(initialValue) {
    if (!initialValue) {
      return {
        compression: GZIP_COMPRESSION,
        content: null
      };
    }
    try {
      const value = JSON.stringify(initialValue);
      const compressed = await (0, _gzip.compress)(value);
      const content = compressed.toString(TO_STORAGE_ENCODING);
      return {
        compression: GZIP_COMPRESSION,
        content
      };
    } catch (ex) {
      console.log(`Error while compressing page content: ${ex.message}`);
    }
    return {
      compression: GZIP_COMPRESSION,
      content: null
    };
  }
  async decompress(value) {
    if (!value?.content) {
      return null;
    }
    try {
      const buf = await (0, _gzip.decompress)(convertToBuffer(value.content));
      const result = buf.toString(FROM_STORAGE_ENCODING);
      return JSON.parse(result);
    } catch (ex) {
      console.log("Error while transforming long-text.");
      console.log(ex.message);
      return "";
    }
  }
}
exports.GzipContentCompressionPlugin = GzipContentCompressionPlugin;

//# sourceMappingURL=GzipContentCompressionPlugin.js.map