"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CloneTranslatableCollectionUseCase = void 0;
var _error = require("@webiny/error");
var _ = require("../..");
class CloneTranslatableCollectionUseCase {
  constructor(context) {
    this.context = context;
  }
  async execute({
    sourceCollectionId,
    newCollectionId
  }) {
    // Clone the translatable collection.
    const getCollection = new _.GetTranslatableCollectionUseCase(this.context);
    const baseCollection = await getCollection.execute(sourceCollectionId);
    if (!baseCollection) {
      throw new _error.WebinyError({
        code: "SOURCE_COLLECTION_NOT_FOUND",
        message: `TranslatableCollection ${sourceCollectionId} was not found!`
      });
    }
    const saveCollection = new _.SaveTranslatableCollectionUseCase(this.context);
    return await saveCollection.execute({
      collectionId: newCollectionId,
      items: baseCollection.getItems().map(item => ({
        itemId: item.itemId,
        value: item.value,
        // We want to preserve the modification date, so we forward the current value!
        modifiedOn: item.modifiedOn.toISOString(),
        context: item.context
      }))
    });
  }
}
exports.CloneTranslatableCollectionUseCase = CloneTranslatableCollectionUseCase;

//# sourceMappingURL=CloneTranslatableCollectionUseCase.js.map